#include "filter01.h"
#include "stdio.h"

//---------------------------------------------------
filter01::filter01()
{
	imageIn			= NULL;
	imageOut		= vtkImageData::New();
	newMin			= 0;
	newMax			= 1000;
	outputFormatSTR	= "SAME";
}


//---------------------------------------------------
filter01::~filter01()
{
	imageOut->Delete();
}

//---------------------------------------------------
void filter01::SetImage(vtkImageData *img)
{
	imageIn = img;
}

//---------------------------------------------------
void filter01::SetNewMinMax(double min, double max)
{
	newMin = min;
	newMax = max;
}

//---------------------------------------------------
void filter01::SetOutputFormat(std::string format)
{
	outputFormatSTR = format;
}

//---------------------------------------------------
vtkImageData *filter01::GetOutputImage()
{
	return imageOut;
}

//---------------------------------------------------
void filter01::Run()
{
	double range[2];
	double spc[6];
	int dim[3];
	int ext[6];
	double value;
	double newValue;
	int outputformat;
	
	if (imageIn!=0)
	{
		if (outputFormatSTR=="")						outputformat = imageIn->GetScalarType();
		else if (outputFormatSTR=="SAME")				outputformat = imageIn->GetScalarType();
		else if (outputFormatSTR=="VTK_BIT")			outputformat = VTK_BIT;
		else if (outputFormatSTR=="VTK_CHAR")			outputformat = VTK_CHAR;
		else if (outputFormatSTR=="VTK_SIGNED_CHAR")	outputformat = VTK_SIGNED_CHAR;
		else if (outputFormatSTR=="VTK_UNSIGNED_CHAR")	outputformat = VTK_UNSIGNED_CHAR;
		else if (outputFormatSTR=="VTK_UNSIGNED_SHORT") outputformat = VTK_UNSIGNED_SHORT;
		else if (outputFormatSTR=="VTK_INT")			outputformat = VTK_INT;
		else if (outputFormatSTR=="VTK_UNSIGNED_INT")	outputformat = VTK_UNSIGNED_INT;
		else if (outputFormatSTR=="VTK_LONG")			outputformat = VTK_LONG;
		else if (outputFormatSTR=="VTK_UNSIGNED_LONG")	outputformat = VTK_UNSIGNED_LONG;
		else if (outputFormatSTR=="VTK_FLOAT")			outputformat = VTK_FLOAT;
		else if (outputFormatSTR=="VTK_DOUBLE")			outputformat = VTK_DOUBLE;
		
		imageOut->Initialize();
		imageOut->SetScalarType( outputformat );	
		imageIn->GetScalarRange(range);
		imageIn->GetSpacing(spc);
		imageOut->SetSpacing( spc );
		imageIn->GetWholeExtent(ext);
		dim[0]=ext[1]-ext[0]+1;
		dim[1]=ext[3]-ext[2]+1;
		dim[2]=ext[5]-ext[4]+1;
		imageOut->SetDimensions( dim[0] , dim[1], dim[2] );
		imageOut->AllocateScalars();

		double difrange = range[1]-range[0];
		double newdifrange = newMax-newMin;
		
		int i,j,k;
		for (i=0; i<dim[0]; i++)
		{
			for (j=0; j<dim[1]; j++)
			{
				for (k=0; k<dim[2]; k++)
				{
					value = imageIn->GetScalarComponentAsDouble(i,j,k,0);
					newValue = ((value*(-1)+range[1])/difrange)*newdifrange + newMin;
					imageOut->SetScalarComponentFromDouble (i,j,k, 0, newValue);
				} // for k
			} // for j
		} // for i
	} // if
}
